//
// C++ Implementation: app
//
// Description: 
//
//
// Author: Christian Hubinger <e9806056@student.tuwien.ac.at>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "app.h"

// #include <tqlcdnumber.h>
// #include <tqlayout.h>
// 
// // KDE includes
// #include <tdeglobal.h>
// #include <tdelocale.h>
// #include <tdeaboutdata.h>
// #include <tdeconfig.h>
// #include <tdeapplication.h>
// #include <tdemessagebox.h>
// #include <tdeapplication.h>
// #include <tdemessagebox.h>
// #include <dcopclient.h>
// #include <tdeaboutapplication.h>


/*
#include "kmfsystray.h"
#include "kmfiptwatcher.h"
#include "mainwidget.h"
*/

MainApp::MainApp() : TDEApplication() {


	// Get the current application configuration handle
//	KMessageBox::information( 0, i18n( "Starting Deamon" ) );

//	TDEConfig *ksConfig = config();
//	KMFIPTWatcher *watch = new KMFIPTWatcher( this, "KMFIPTWatcher" );
//	MainWidget *mainWid = new MainWidget( 0 );
//	connect( watch, TQT_SIGNAL( sigUpdateActive( bool ) ), mainWid, TQT_SLOT( slotSetRunningStatus( bool ) ) );
//	connect( watch, TQT_SIGNAL( sigUpdateRuleCount( const TQString&, const TQString&, int ) ), 
//		mainWid, TQT_SIGNAL( sigUpdateRuleCount( const TQString&, const TQString&, int ) ) );

//	connect( mainWid, TQT_SIGNAL( sigQueryDetails( bool ) ), watch, TQT_SLOT( slotQueryDetails( bool ) ) );
/*	
	TQHBoxLayout *_layout = new TQHBoxLayout(this);
  	_layout->add(mainWid);*/





}


MainApp::~MainApp() {}


